pub struct Manager { /* private fields */ }Expand description
Manager of the window subsystem.
This manager is accessible from (and only from) the foreground thread. It provides the interfaces to create the window, winit objects and access active event loop.
Implementations
Sourceimpl Manager
impl Manager
Sourcepub fn set_draining_foreground_loopback(&self, value: bool)
pub fn set_draining_foreground_loopback(&self, value: bool)
Set whether the event loop will drain the foreground loopback tasks.
If set, the event loop will call
aeth::task::drain_foreground_loopback automatically
whenever the foreground tasks can run. Otherwise the
application must invoke the draining function manually.
Sourcepub async fn create_window(
&self,
attrs: WindowAttributes,
) -> Result<Window, RequestError>
pub async fn create_window( &self, attrs: WindowAttributes, ) -> Result<Window, RequestError>
Create a managed window instance.
Please notice you should always call this function
instead of grabbing the active event loop and invoke
active_event_loop.create_window manually, otherwise
there’s no way to deliver window event to your window.
See aeth::window::Window for more detail.
Sourcepub fn wakeup_event_sub(&self) -> Sub<WakeUpEvent>
pub fn wakeup_event_sub(&self) -> Sub<WakeUpEvent>
Obtain the wakeup event subscriber.
Sourcepub fn device_event_sub(&self) -> Sub<DeviceEvent>
pub fn device_event_sub(&self) -> Sub<DeviceEvent>
Obtain the device event subscriber.