Window

Struct Window 

pub struct Window { /* private fields */ }
Managed window handle.

Things like redrawing a window, accepting a user interaction, are passed by window events. A graphical program runs an event loop to poll these events and handles them. The window subsystem mediates the interaction between the event loop and async task process. When a window event happens, it will need to locate the window to deliver the window event. This is impossible without getting the windows managed.

Therefore, we need such an object. It’s built on the top of an winit::window::Window, registered to the window subsystem and expose a subscriber window_event_sub for receiving window events dedicated to this window.

Implementations

Source

impl Window

pub fn set_refreshing(&mut self, enable: bool)

Set the window as being refreshing or not.

By setting this window as being refreshing, every time the event loop is about to sleep, a redraw event is going to be queued for this window. This is required for video applications and games.

pub fn is_refreshing(&self) -> bool

Check if the window is refreshing or not.

pub fn window_event_sub(&self) -> Sub<WindowEvent>

Obtain the window event subscriber dedicated to this window.