AccessWinitActiveEventLoopExt

Trait AccessWinitActiveEventLoopExt 

pub trait AccessWinitActiveEventLoopExt: AccessWinitActiveEventLoop {
    // Provided methods
    async fn create_proxy(&self) -> EventLoopProxy { ... }
    async fn create_custom_cursor(
        &self,
        custom_cursor: CustomCursorSource,
    ) -> Result<CustomCursor, RequestError> { ... }
    async fn available_monitors(
        &self,
    ) -> Box<dyn Iterator<Item = MonitorHandle>> { ... }
    async fn primary_monitor(&self) -> Option<MonitorHandle> { ... }
    async fn listen_device_events(&self, allowed: DeviceEvents) { ... }
    async fn system_theme(&self) -> Option<Theme> { ... }
    async fn set_control_flow(&self, flow: ControlFlow) { ... }
    async fn control_flow(&self) -> ControlFlow { ... }
    async fn owned_display_handle(&self) -> OwnedDisplayHandle { ... }
}
Trait extension to forawrd winit::event_loop::ActiveEventLoop methods.

Please notice winit::event_loop::ActiveEventLoop::create_window will never be forwarded. You must always not do that, instead you must call crate::Manager::create_window to get things right.

The winit::event_loop::ActiveEventLoop::exit is not forwarded either. We treat the exiting of the main coroutine as exiting the event loop.

Provided Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors