AccessWinitWindowExt

Trait AccessWinitWindowExt 

pub trait AccessWinitWindowExt: AccessWinitWindow {
Show 17 methods // Provided methods fn id(&self) -> WindowId { ... } fn scale_factor(&self) -> f64 { ... } fn pre_present_notify(&self) { ... } fn surface_position(&self) -> PhysicalPosition<i32> { ... } fn outer_position(&self) -> Result<PhysicalPosition<i32>, RequestError> { ... } fn set_outer_position(&self, position: Position) { ... } fn surface_size(&self) -> PhysicalSize<u32> { ... } fn request_surface_size(&self, size: Size) -> Option<PhysicalSize<u32>> { ... } fn outer_size(&self) -> PhysicalSize<u32> { ... } fn safe_area(&self) -> PhysicalInsets<u32> { ... } fn set_min_surface_size(&self, min_size: Option<Size>) { ... } fn set_max_surface_size(&self, min_size: Option<Size>) { ... } fn surface_resize_increments(&self) -> Option<PhysicalSize<u32>> { ... } fn set_surface_resize_increments(&self, increments: Option<Size>) { ... } fn title(&self) -> String { ... } fn set_title(&self, title: &str) { ... } fn set_transparent(&self, transparent: bool) { ... }
}
Trait extension to forawrd winit::window::Window methods.

Please notice that we forward method based on the requirement of other modules from aeth-rs, and not necessarily all methods are forwarded. In that case, you may add your required method to this trait extension through pull request, or implement your own extension, just like what we are doing here.

Provided Methods

fn id(&self) -> WindowId

fn scale_factor(&self) -> f64

fn pre_present_notify(&self)

fn surface_position(&self) -> PhysicalPosition<i32>

fn outer_position(&self) -> Result<PhysicalPosition<i32>, RequestError>

fn set_outer_position(&self, position: Position)

fn surface_size(&self) -> PhysicalSize<u32>

fn request_surface_size(&self, size: Size) -> Option<PhysicalSize<u32>>

fn outer_size(&self) -> PhysicalSize<u32>

fn safe_area(&self) -> PhysicalInsets<u32>

fn set_min_surface_size(&self, min_size: Option<Size>)

fn set_max_surface_size(&self, min_size: Option<Size>)

fn surface_resize_increments(&self) -> Option<PhysicalSize<u32>>

fn set_surface_resize_increments(&self, increments: Option<Size>)

fn title(&self) -> String

fn set_title(&self, title: &str)

fn set_transparent(&self, transparent: bool)

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors